# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/modelconfig/model.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/modelconfig/model.proto',
  package='ai.cogneed.api.modelconfig.model',
  syntax='proto3',
  serialized_options=_b('\n ai.cogneed.api.modelconfig.modelP\001'),
  serialized_pb=_b('\n5cogneed-protos/ai/cogneed/api/modelconfig/model.proto\x12 ai.cogneed.api.modelconfig.model\".\n\x06\x43reate\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\t\"\xe9\x01\n\x05Model\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\ruse_case_uuid\x18\x02 \x01(\t\x12\r\n\x05major\x18\x03 \x01(\t\x12\r\n\x05minor\x18\x04 \x01(\x05\x12\x36\n\x05state\x18\x05 \x01(\x0e\x32\'.ai.cogneed.api.modelconfig.model.State\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\x03\x12\x12\n\nupdated_at\x18\t \x01(\x03\x12\x15\n\rin_production\x18\n \x01(\x08\"B\n\x04List\x12\x15\n\ruse_case_uuid\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x15\n\rrows_per_page\x18\x04 \x01(\x05\"\x19\n\tModelUuid\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"W\n\x0cListResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x38\n\x07results\x18\x02 \x03(\x0b\x32\'.ai.cogneed.api.modelconfig.model.Model\"\x0c\n\nResponseOk*h\n\x05State\x12\x08\n\x04INIT\x10\x00\x12\x14\n\x10TRAINING_PENDING\x10\x01\x12\x18\n\x14TRAINING_IN_PROGRESS\x10\x02\x12\x12\n\x0eTRAINING_ERROR\x10\x03\x12\x11\n\rTRAINING_DONE\x10\x04\x32\xd0\x05\n\x0cModelService\x12`\n\x06\x63reate\x12(.ai.cogneed.api.modelconfig.model.Create\x1a,.ai.cogneed.api.modelconfig.model.ResponseOk\x12^\n\x04list\x12&.ai.cogneed.api.modelconfig.model.List\x1a..ai.cogneed.api.modelconfig.model.ListResponse\x12\\\n\x04read\x12+.ai.cogneed.api.modelconfig.model.ModelUuid\x1a\'.ai.cogneed.api.modelconfig.model.Model\x12\x63\n\x07upgrade\x12+.ai.cogneed.api.modelconfig.model.ModelUuid\x1a+.ai.cogneed.api.modelconfig.model.ModelUuid\x12j\n\rstartTraining\x12+.ai.cogneed.api.modelconfig.model.ModelUuid\x1a,.ai.cogneed.api.modelconfig.model.ResponseOk\x12\x63\n\x06\x64\x65ploy\x12+.ai.cogneed.api.modelconfig.model.ModelUuid\x1a,.ai.cogneed.api.modelconfig.model.ResponseOk\x12j\n\rmarkAsTrained\x12+.ai.cogneed.api.modelconfig.model.ModelUuid\x1a,.ai.cogneed.api.modelconfig.model.ResponseOkB$\n ai.cogneed.api.modelconfig.modelP\x01\x62\x06proto3')
)

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='ai.cogneed.api.modelconfig.model.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAINING_PENDING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAINING_IN_PROGRESS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAINING_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAINING_DONE', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=573,
  serialized_end=677,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
INIT = 0
TRAINING_PENDING = 1
TRAINING_IN_PROGRESS = 2
TRAINING_ERROR = 3
TRAINING_DONE = 4



_CREATE = _descriptor.Descriptor(
  name='Create',
  full_name='ai.cogneed.api.modelconfig.model.Create',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.modelconfig.model.Create.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.modelconfig.model.Create.major', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=137,
)


_MODEL = _descriptor.Descriptor(
  name='Model',
  full_name='ai.cogneed.api.modelconfig.model.Model',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.model.Model.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.modelconfig.model.Model.use_case_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.modelconfig.model.Model.major', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minor', full_name='ai.cogneed.api.modelconfig.model.Model.minor', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='ai.cogneed.api.modelconfig.model.Model.state', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='ai.cogneed.api.modelconfig.model.Model.created_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_by', full_name='ai.cogneed.api.modelconfig.model.Model.updated_by', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='ai.cogneed.api.modelconfig.model.Model.created_at', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='ai.cogneed.api.modelconfig.model.Model.updated_at', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_production', full_name='ai.cogneed.api.modelconfig.model.Model.in_production', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=373,
)


_LIST = _descriptor.Descriptor(
  name='List',
  full_name='ai.cogneed.api.modelconfig.model.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='use_case_uuid', full_name='ai.cogneed.api.modelconfig.model.List.use_case_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='ai.cogneed.api.modelconfig.model.List.page', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows_per_page', full_name='ai.cogneed.api.modelconfig.model.List.rows_per_page', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=441,
)


_MODELUUID = _descriptor.Descriptor(
  name='ModelUuid',
  full_name='ai.cogneed.api.modelconfig.model.ModelUuid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.modelconfig.model.ModelUuid.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=468,
)


_LISTRESPONSE = _descriptor.Descriptor(
  name='ListResponse',
  full_name='ai.cogneed.api.modelconfig.model.ListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='ai.cogneed.api.modelconfig.model.ListResponse.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='ai.cogneed.api.modelconfig.model.ListResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=557,
)


_RESPONSEOK = _descriptor.Descriptor(
  name='ResponseOk',
  full_name='ai.cogneed.api.modelconfig.model.ResponseOk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=559,
  serialized_end=571,
)

_MODEL.fields_by_name['state'].enum_type = _STATE
_LISTRESPONSE.fields_by_name['results'].message_type = _MODEL
DESCRIPTOR.message_types_by_name['Create'] = _CREATE
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
DESCRIPTOR.message_types_by_name['List'] = _LIST
DESCRIPTOR.message_types_by_name['ModelUuid'] = _MODELUUID
DESCRIPTOR.message_types_by_name['ListResponse'] = _LISTRESPONSE
DESCRIPTOR.message_types_by_name['ResponseOk'] = _RESPONSEOK
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Create = _reflection.GeneratedProtocolMessageType('Create', (_message.Message,), dict(
  DESCRIPTOR = _CREATE,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.model_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.model.Create)
  ))
_sym_db.RegisterMessage(Create)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), dict(
  DESCRIPTOR = _MODEL,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.model_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.model.Model)
  ))
_sym_db.RegisterMessage(Model)

List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), dict(
  DESCRIPTOR = _LIST,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.model_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.model.List)
  ))
_sym_db.RegisterMessage(List)

ModelUuid = _reflection.GeneratedProtocolMessageType('ModelUuid', (_message.Message,), dict(
  DESCRIPTOR = _MODELUUID,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.model_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.model.ModelUuid)
  ))
_sym_db.RegisterMessage(ModelUuid)

ListResponse = _reflection.GeneratedProtocolMessageType('ListResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTRESPONSE,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.model_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.model.ListResponse)
  ))
_sym_db.RegisterMessage(ListResponse)

ResponseOk = _reflection.GeneratedProtocolMessageType('ResponseOk', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSEOK,
  __module__ = 'cogneed_protos.ai.cogneed.api.modelconfig.model_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.modelconfig.model.ResponseOk)
  ))
_sym_db.RegisterMessage(ResponseOk)


DESCRIPTOR._options = None

_MODELSERVICE = _descriptor.ServiceDescriptor(
  name='ModelService',
  full_name='ai.cogneed.api.modelconfig.model.ModelService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=680,
  serialized_end=1400,
  methods=[
  _descriptor.MethodDescriptor(
    name='create',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.create',
    index=0,
    containing_service=None,
    input_type=_CREATE,
    output_type=_RESPONSEOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='list',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.list',
    index=1,
    containing_service=None,
    input_type=_LIST,
    output_type=_LISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='read',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.read',
    index=2,
    containing_service=None,
    input_type=_MODELUUID,
    output_type=_MODEL,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='upgrade',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.upgrade',
    index=3,
    containing_service=None,
    input_type=_MODELUUID,
    output_type=_MODELUUID,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='startTraining',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.startTraining',
    index=4,
    containing_service=None,
    input_type=_MODELUUID,
    output_type=_RESPONSEOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='deploy',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.deploy',
    index=5,
    containing_service=None,
    input_type=_MODELUUID,
    output_type=_RESPONSEOK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='markAsTrained',
    full_name='ai.cogneed.api.modelconfig.model.ModelService.markAsTrained',
    index=6,
    containing_service=None,
    input_type=_MODELUUID,
    output_type=_RESPONSEOK,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELSERVICE)

DESCRIPTOR.services_by_name['ModelService'] = _MODELSERVICE

# @@protoc_insertion_point(module_scope)
